@@ -17,11 +17,11 @@ Mail::SPF - An object-oriented implementation of Sender Policy Framework
 
 =head1 VERSION
 
-version 3.20240827
+version 3.20250505
 
 =cut
 
-our $VERSION = '3.20240827'; # VERSION
+our $VERSION = '3.20250505'; # VERSION
 
 use warnings;
 use strict;
@@ -59,7 +59,8 @@ use constant FALSE  => not TRUE;
 =head1 DESCRIPTION
 
 B<Mail::SPF> is an object-oriented implementation of Sender Policy Framework
-(SPF).  See L<http://www.openspf.org> for more information about SPF.
+(SPF).  See L<https://tools.ietf.org/html/rfc7208> for more information about
+SPF.
 
 This class collection aims to fully conform to the SPF specification (RFC
 4408) so as to serve both as a production quality SPF implementation and as a
@@ -78,11 +79,11 @@ included with Mail::SPF.
 
 =item The SPF project
 
-L<http://www.openspf.org>
+L<http://www.open-spf.org/>
 
-=item The SPFv1 specification (RFC 4408)
+=item The SPFv1 specification (RFC 7208)
 
-L<http://www.openspf.org/Specifications>, L<http://tools.ietf.org/html/rfc4408>
+L<http://www.open-spf.org/Specifications>, L<https://tools.ietf.org/html/rfc7208>
 
 =back
 
